# powersall

lottery analysis and number generator tool in python

## install

`pip3 install powersall`

## usage

`powersall`

This downloads the last years worth of powerball data in csv format as well as displays it on the screen. Enjoy.

